/**************************************************************************//**
*   @file   ad7298.h
*   @brief  Header file of AD7298 Driver for NIOS processor.
*   @author grohmast
*
*******************************************************************************
* Copyright 2011(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR IMPLIED
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT, MERCHANTABILITY
* AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
* INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
*******************************************************************************
*   SVN Revision: 158
******************************************************************************/
#ifndef _AD7298_H_
#define _AD7298_H_
#ifdef AD7298_GLOBALS
	#define AD7298_EXT extern
#else
	#define AD7298_EXT
#endif

/*****************************************************************************/
/* Include Files                                                           	 */
/*****************************************************************************/
#include "adi.h"
#if (USE_AD7298 == 1)

/*****************************************************************************/
/* AD7298                                                                    */
/*****************************************************************************/
#define VIN0			0							// define mask in receive channel description
#define VIN1			1
#define VIN2			2
#define VIN3			3
#define VIN4			4
#define VIN5			5
#define VIN6			6
#define VIN7			7
#define TSENS			8
#define TAVG			9
#define D_MASK(x,Chan)	(((x&(Chan<<12))>>12)==Chan)
#define ADCCH0			(1<<(8-VIN0))				// define position in send channel description
#define ADCCH1			(1<<(8-VIN1))
#define ADCCH2			(1<<(8-VIN2))
#define ADCCH3			(1<<(8-VIN3))
#define ADCCH4			(1<<(8-VIN4))
#define ADCCH5			(1<<(8-VIN5))
#define ADCCH6			(1<<(8-VIN6))
#define ADCCH7			(1<<(8-VIN7))				// bit1 -> D6
#define CHTSENS			(1<<(8-TSENS))				// bit0 -> D5
#define CHTAVG			(1<<(9-TAVG))				// bit0 -> D5

/*****************************************************************************/
/* AD7298                                                                    */
/*****************************************************************************/
typedef union ad7298_data_union {
		unsigned char c[2];
		unsigned int  w;
}ad7298_data_t;

/*****************************************************************************/
/* SPI                                                                       */
/*****************************************************************************/
#define AD7298_SPI		SPI_0_P0_BASE
#define AD7298_SPI_CFG	(SPI0_ena | SPI0_inv)

/*****************************************************************************/
/* Monitored Variables Declarations                                          */
/*****************************************************************************/
AD7298_EXT ad7298_data_t 	ad7298_data[9];		// ADC Data
AD7298_EXT int 				ad7298_temperatur;	// AD7298 temp
#endif //(USE_AD7298 == 1)

/*****************************************************************************/
/* Functions Prototypes                                                      */
/*****************************************************************************/
int AD7298_Init(void);
int AD7298_UpdateParameters(void);
int AD7298_Set(int value);
int AD7298_GetOneAdValue(void);
int AD7298_SetChannel(int chan);
int AD7298_RepeatChannel(int chan);
unsigned int AD7298_CalcTemp(int value);
int AD7298_Get(unsigned char numberofRead);
#endif /* _AD7298_H_ */
